'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.RealtimeChannel = exports.config = exports.default = undefined;

var _promise = require('babel-runtime/core-js/promise');

var _promise2 = _interopRequireDefault(_promise);

var _get2 = require('lodash/get');

var _get3 = _interopRequireDefault(_get2);

var _has2 = require('lodash/has');

var _has3 = _interopRequireDefault(_has2);

var _board = require('./board');

Object.defineProperty(exports, 'default', {
  enumerable: true,
  get: function get() {
    return _interopRequireDefault(_board).default;
  }
});

require('@ciscospark/internal-plugin-mercury');

require('@ciscospark/internal-plugin-encryption');

require('@ciscospark/internal-plugin-conversation');

require('@ciscospark/internal-plugin-feature');

var _sparkCore = require('@ciscospark/spark-core');

var _board2 = _interopRequireDefault(_board);

var _realtimeChannel = require('./realtime-channel');

var _realtimeChannel2 = _interopRequireDefault(_realtimeChannel);

var _config = require('./config');

var _config2 = _interopRequireDefault(_config);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/*!
 * Copyright (c) 2015-2017 Cisco Systems, Inc. See LICENSE file.
 */

(0, _sparkCore.registerInternalPlugin)('board', _board2.default, {
  config: _config2.default,
  payloadTransformer: {
    predicates: [{
      name: 'decryptContents',
      direction: 'inbound',

      test: function test(ctx, options) {
        // we must have items
        if (!(0, _has3.default)(options, 'body.items') || options.body.items.length === 0) {
          return _promise2.default.resolve(false);
        }

        // we must have a contentId
        if (!(0, _get3.default)(options, 'body.items[0].contentId')) {
          return _promise2.default.resolve(false);
        }

        // we must have a encryptionKeyUrl
        /* istanbul ignore if */
        if (!(0, _get3.default)(options, 'body.items[0].encryptionKeyUrl')) {
          return _promise2.default.resolve(false);
        }

        // we must have a payload or file
        /* istanbul ignore if */
        if (!(0, _get3.default)(options, 'body.items[0].payload') && !(0, _get3.default)(options, 'body.items[0].file')) {
          return _promise2.default.resolve(false);
        }

        return _promise2.default.resolve(true);
      },
      extract: function extract(options) {
        return _promise2.default.resolve(options.body);
      }
    }, {
      name: 'encryptChannel',
      direction: 'outbound',

      test: function test(ctx, options) {
        if (ctx.spark.internal.device.isSpecificService('board', options.uri) && (0, _has3.default)(options, 'body.aclUrlLink')) {
          return _promise2.default.resolve(true);
        }

        return _promise2.default.resolve(false);
      },
      extract: function extract(options) {
        return _promise2.default.resolve(options.body);
      }
    }],
    transforms: [{
      name: 'decryptContents',
      direction: 'inbound',

      fn: function fn(ctx, object) {
        return ctx.spark.internal.board.decryptContents(object).then(function (decryptedContents) {
          object.items = decryptedContents;
        });
      }
    }, {
      name: 'encryptChannel',
      direciton: 'outbound',
      fn: function fn(ctx, object) {
        return ctx.spark.internal.encryption.kms.createUnboundKeys({ count: 1 }).then(function (keys) {
          var key = keys[0];

          object.defaultEncryptionKeyUrl = key.uri;
          object.kmsMessage.keyUris.push(key.uri);

          return ctx.transform('encryptKmsMessage', object);
        });
      }
    }]
  }
});

exports.config = _config2.default;
exports.RealtimeChannel = _realtimeChannel2.default;
//# sourceMappingURL=index.js.map
